@@ -44,6 +44,8 @@ Further updates:
 
 =item * version 0.94, published on October 2, 2006
 
+=item * version 0.95, published on October 9, 2006
+
 =back
 
 =head1 SEE ALSO
@@ -72,6 +74,7 @@ AAYARS
 ABALAMA
 ABARCLAY
 ABCDEFGH
+ABE
 ABELEW
 ABELTJE
 ABERGMAN
@@ -98,6 +101,7 @@ ACCARDO
 ACDALTON
 ACESAVER
 ACESTER
+ACG
 ACH
 ACHEN
 ACHOUNG
@@ -217,6 +221,7 @@ ALEXMC
 ALEXMV
 ALEXP
 ALEXPRECH
+ALEXS
 ALFALPHA
 ALFIE
 ALFO
@@ -266,6 +271,7 @@ AMRUTA
 AMS
 AMUGNOLO
 AMURREN
+AMV
 AMW
 ANAGHAKK
 ANARION
@@ -1352,6 +1358,7 @@ DNAD
 DNARAYAN
 DNEIL
 DNORTH
+DNS
 DOCG
 DOCTORMO
 DODGER
@@ -1724,6 +1731,7 @@ FSPEISER
 FTASSIN
 FTOBIN
 FUJIWARA
+FUKUDA
 FUZZ
 FVANDUN
 FVULTO
@@ -1867,6 +1875,7 @@ GREGARYH
 GREGFAST
 GREGG
 GREGOR
+GREGORY
 GREIZHANG
 GRENDELUK
 GREP
@@ -2524,6 +2533,7 @@ JOCHEN
 JOEHIL
 JOEJIANG
 JOELH
+JOENIO
 JOEOFCLEW
 JOEPHAYES
 JOESUF
@@ -2691,6 +2701,7 @@ JWIEGLEY
 JWILEY
 JWILLIAMS
 JWOODYATT
+JWU
 JXH
 JZAWODNY
 JZUCKER
@@ -3022,6 +3033,7 @@ LMASARA
 LMEYER
 LMJM
 LMOLNAR
+LMUELLER
 LOCAL
 LOCATION
 LOCHMATT
@@ -3225,6 +3237,7 @@ MBOECK
 MBRECH
 MBSTE
 MBURNS
+MBUSIK
 MCAFEE
 MCANTONI
 MCARR
@@ -3639,6 +3652,7 @@ NEVDULL
 NEVES
 NEVETS
 NEXEN
+NEZUMI
 NFMNUNES
 NGEREN
 NGLEDHILL
@@ -3760,6 +3774,7 @@ OMEGA
 OMKELLOGG
 ONDR
 ONEIROS
+OOGLEK
 OPHIUCI
 OPI
 OPIATE
@@ -3794,6 +3809,7 @@ PAJAS
 PAJOUT
 PALANT
 PANDICH
+PANOLEX
 PAOLO
 PAPILLION
 PARASEW
@@ -3965,6 +3981,7 @@ PLAMBERT
 PLANET
 PLANK
 PLATO
+PLEGALL
 PLEXUS
 PLIAM
 PLISCO
@@ -4346,6 +4363,7 @@ RRG
 RRINDELS
 RRS
 RRWO
+RSANDBERG
 RSARAN
 RSAVAGE
 RSCHUPP
@@ -4448,6 +4466,7 @@ SBALA
 SBASHTON
 SBAZZI
 SBECK
+SBEE
 SBERKHOLZ
 SBERRY
 SBHARR
@@ -5251,6 +5270,7 @@ WARDY
 WARMING
 WARREN
 WARRENM
+WARRINGD
 WARTHURT
 WASX
 WATANABE
